#ifndef GUARD_processvectors_h
#define GUARD_processvectors_h

//#include "fff.h"
#include "aff.h"
//#include<Rcpp.h>

double cpp_computeFFFMean(Rcpp::NumericVector, double);

double cpp_computeAFFMean(Rcpp::NumericVector, double);


#endif
